<template>
    <v-dialog
        width="450"
        v-model="changeMobileDialog"
    >

        <v-card>

            <v-card-text>

                <v-text-field
                    type="tel"
                    autofocus
                    v-model="new_mobile"
                    :mask="mobileMask"
                    length="10"
                    label="Enter New Mobile Number"
                ></v-text-field>

                <v-text-field
                    type="tel"
                    class="mt-3 mb-3"
                    v-if="verificationProcess"
                    autofocus
                    :mask="otp_format"
                    v-model="verification_code"
                    label="Enter Verification Code"
                ></v-text-field>

                <v-btn
                    large
                    block
                    color="success"
                    :loading="loading"
                    @click="changeNumber"
                    v-if="new_mobile != mobile && new_mobile.length == 10 && changeNumberProcess"
                >
                    Change Mobile
                </v-btn>

                <v-btn
                    large
                    block
                    color="success"
                    :loading="loading"
                    @click="verifyNumber"
                    v-if="new_mobile != mobile && verificationProcess"
                >
                    Verify
                </v-btn>

            </v-card-text>

        </v-card>

    </v-dialog>
</template>

<script>
export default {
    watch: {
        dialogTrigger (val) {
            if (val) {
                this.changeMobileDialog = val;
            }
        }
    },
    methods: {
        verifyNumber () {

            if (this.new_mobile.length != 10) {
                this.$store.commit('showSnackBar', 'Mobile number must be of 10 digits');
                return true;
            }

            var url = 'https://cardboardbalingwire.com/shop/module/itiwas_api/api?comp=process&action=changeCustomerMobileNumberVerification';

            var form_data = new FormData();
            form_data.append('mobile', this.new_mobile);
            form_data.append('verification_code', this.verification_code);

            this.loading = true;

            this.$axiosx.post(url, form_data, {
                withCredentials: true
            })
            .then((res) => {

                this.loading = false;

                if (res.data.status == 'success') {
                    this.changeNumberProcess = false;
                    this.verificationProcess = false;
                    this.changeMobileDialog = false;

                    this.$store.commit('showSnackBar', 'New mobile number has been tied to your account');

                    this.$emit('success', 'Done');
                }

                if (res.data.status == 'error') {

                    this.$store.commit('showSnackBar', res.data.message);

                }

            })
            .catch((e) => {

                this.loading = false;

            });

        },
        changeNumber () {

            if (this.new_mobile.length != 10) {
                this.$store.commit('showSnackBar', 'Mobile number must be of 10 digits');
                return true;
            }

            var url = 'https://cardboardbalingwire.com/shop/module/itiwas_api/api?comp=process&action=changeCustomerMobileNumber';

            var form_data = new FormData();
            form_data.append('mobile', this.new_mobile);

            this.loading = true;

            this.$axiosx.post(url, form_data)
            .then((res) => {

                this.loading = false;

                if (res.data.status == 'success') {
                    this.changeNumberProcess = false;
                    this.verificationProcess = true;
                }

                if (res.data.status == 'error') {

                    this.$store.commit('showSnackBar', res.data.message);

                }

                console.log(res);

            })
            .catch((e) => {

                this.loading = false;

            });

        }
    },
    props: {
        dialogTrigger: {},
        mobile: {
            default: null
        }
    },
    data () {
        return {
            otp_format: '###-###',
            verificationProcess: false,
            changeNumberProcess: true,
            mobileMask: 'phone',
            loading: false,
            verification_code: false,
            changeMobileDialog: false,
            new_mobile: this.mobile,
            verification_code: null
        }
    }

}
</script>
